@@ -22,6 +22,7 @@ import salt.ext.tornado.concurrent
 import salt.ext.tornado.gen
 import salt.ext.tornado.ioloop
 import salt.log.setup
+import salt.master
 import salt.payload
 import salt.transport.client
 import salt.transport.mixins.auth
@@ -384,7 +385,7 @@ class AsyncZeroMQReqChannel(salt.transport.client.ReqChannel):
         signed_msg = pcrypt.loads(ret[dictkey])
 
         # Validate the master's signature.
-        master_pubkey_path = os.path.join(self.opts["pki_dir"], "minion_master.pub")
+        master_pubkey_path = os.path.join(self.opts["pki_dir"], self.auth.mpub)
         if not salt.crypt.verify_signature(
             master_pubkey_path, signed_msg["data"], signed_msg["sig"]
         ):
@@ -993,7 +994,7 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
     def connect(self):
         return salt.ext.tornado.gen.sleep(5)
 
-    def _publish_daemon(self, log_queue=None):
+    def _publish_daemon(self, log_queue=None, secrets=None):
         """
         Bind to the interface specified in the configuration file
         """
@@ -1010,6 +1011,9 @@ class ZeroMQPubServerChannel(salt.transport.server.PubServerChannel):
             salt.log.setup.set_multiprocessing_logging_queue(log_queue)
             salt.log.setup.setup_multiprocessing_logging(log_queue)
 
+        if secrets is not None:
+            salt.master.SMaster.secrets = secrets
+
         # Set up the context
         context = zmq.Context(1)
         # Prepare minion publish socket
